// UVControl.cpp : implementation file
//

#include "stdafx.h"
#include "BIOD_Lite.h"
#include "UVControl.h"

#include "BIOD_LiteDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CUVControl

CUVControl::CUVControl()
{
}

CUVControl::~CUVControl()
{
}


BEGIN_MESSAGE_MAP(CUVControl, CWnd)
	//{{AFX_MSG_MAP(CUVControl)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()


/////////////////////////////////////////////////////////////////////////////
// CUVControl message handlers

void CUVControl::Init(CWnd *pWnd, CgtComPort *pComPort)
{
	m_bControlMode = UV_CONTROL_FRONT;
	m_bLampOn = FALSE;
	m_bManualOn = FALSE;
	m_bIntensityMin = FALSE;
	m_bIntensityMax = FALSE;
	m_iDeviceID = UV_SOURCE_DEVICE_ID_LC8;
	m_strDeviceName = UV_SOURCE_DEVICE_NAME_LC8;
	m_strUVCommRecv = "";

	m_pComPort = pComPort;
	m_pParentWnd = pWnd;

	m_strStatus = "Lamp Status: IDLE";
	PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;
	pUI->SetDlgItemText(IDC_STATIC_UV_STATUS, m_strStatus);
	((CComboBox *)(pUI->GetDlgItem(IDC_COMBO_UV_DEVICE)))->SetCurSel(UV_SOURCE_DEVICE_ID_LC8);
	((CButton *)(pUI->GetDlgItem(IDC_BUTTON_UV_LAMP_ON)))->SetWindowText("Lamp OFF");

	m_iIntensity = 0;
	CString strTemp;
	strTemp.Format("%d", m_iIntensity);
	pUI->SetDlgItemText(IDC_EDIT_UV_INTENSITY, strTemp);

	m_iXCiteUVIntensityIndex = 0;
	
	SetMMTimer(TIMER_EVENT_QUERY_UV_STATUS, 800);
	
	m_iXCiteStatusStep = 0;

}

void CUVControl::SetParentWnd(CWnd *pWnd)
{
	m_pParentWnd = pWnd;
}

void CUVControl::SetComPortHandle(CgtComPort *pComPort)
{
	m_pComPort = pComPort;
}

void CUVControl::SetDevice(int iDeviceID)
{
	m_iDeviceID = iDeviceID;
	PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;
	pUI->GetDlgItem(IDC_STATIC_GROUP_UV_CONTROL)->SetFocus();

	SetMMTimer(TIMER_EVENT_QUERY_UV_STATUS, 200);
}

void CUVControl::CommSend(CString str)
{
	CString strSend = str;	

	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
			
		}
		
	case UV_SOURCE_DEVICE_ID_XCITE:
		{			
			strSend += "\r";	//'\r'
			m_pComPort->sendString(strSend);
		}		
		break;
	default:
		break;
	}
}

void CUVControl::ParseUVData(CString str)
{
	CString strRecv = str;	

	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
			if( strRecv.Find("AT0") >= 0 )
			{
				ParseUVData_LC8Recv_AT0(strRecv);
			}
			else if( strRecv.Find("INP") >= 0 )
			{
				ParseUVData_LC8Recv_INP(strRecv);
			}
			else if( strRecv.Find("INT") >= 0 )
			{
				ParseUVData_LC8Recv_INT(strRecv);
			}
			else if( strRecv.Find("CNT") >= 0 )
			{
				ParseUVData_LC8Recv_CNT(strRecv);
			}
		}
		break;
	case UV_SOURCE_DEVICE_ID_XCITE:
		{
			ParseUVData_XCiteRecv(strRecv);
		}
		break;
	default:
		break;
	}
}


void CUVControl::ParseUVData_LC8Recv_AT0(CString strRecv)
{
	int len, i, j;
	CString strTemp;
	float fShutterTime;	

	len = strRecv.GetLength();

	if( (i=strRecv.Find("AT0")) >= 0 )
	{
		j = len-2;
		strTemp = strRecv.Right(j-(i+2)+1);
		strTemp.Remove('\n');
		strTemp.Remove('\r');

		char *t = strTemp.GetBuffer(10);
		fShutterTime = (float)atof(t);
		strTemp.ReleaseBuffer();
		
		m_iShutterTime = (int) (fShutterTime * 1000);
	//	m_strShutterTime = strTemp;
		m_strShutterTime.Format("%d", m_iShutterTime);

		PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;
		pUI->SetDlgItemText(IDC_EDIT_UV_SHUTTERTIME, m_strShutterTime);
	}
}

void CUVControl::ParseUVData_LC8Recv_INP(CString strRecv)
{
	CString strTemp;
	PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;

	if( strRecv == "INP00" )
	{
		pUI->GetDlgItem(IDC_BUTTON_UV_LAMP_ON)->SetWindowText("Lamp OFF");
		pUI->SetDlgItemText(IDC_STATIC_UV_STATUS, "Lamp Status: OFF");
		m_bLampOn = FALSE;
	}
	else if( strRecv == "INP01" )
	{
		pUI->GetDlgItem(IDC_BUTTON_UV_LAMP_ON)->SetWindowText("Lamp ON");
		pUI->SetDlgItemText(IDC_STATIC_UV_STATUS, "Lamp Status: ON");
		m_bLampOn = TRUE;
	}
	else if( strRecv == "INP03" )
	{
		//Lamp Stable!
		m_strStatus = "Lamp Status: STABLE";
		pUI->SetDlgItemText(IDC_STATIC_UV_STATUS, m_strStatus);
		pUI->GetDlgItem(IDC_BUTTON_UV_LAMP_ON)->SetWindowText("Lamp ON");
		pUI->SetDlgItemText(IDC_STATIC_UV_STATUS, "Lamp Status: ON");

		if( m_bManualOn == TRUE )
		{
			strTemp = "Closed";		
			pUI->GetDlgItem(IDC_BUTTON_UV_SHUTTER_MANUAL)->SetWindowText(strTemp);
			m_bManualOn = FALSE;
		}
	}
	else if( strRecv == "INP07" )
	{
		if( m_bManualOn == FALSE )
		{
			strTemp = "Opened";	
			pUI->GetDlgItem(IDC_BUTTON_UV_SHUTTER_MANUAL)->SetWindowText(strTemp);
			m_bManualOn = TRUE;
		}
	}
	else if( (strRecv == "INP08") || (strRecv == "INP09") )
	{
		//LC8 intensity reaches MAX value.
		pUI->GetDlgItem(IDC_BUTTON_UV_LAMP_ON)->SetWindowText("Lamp MIN");
		m_bIntensityMin = TRUE;
		m_bIntensityMax = FALSE;
	}
	else if( (strRecv == "INP10") || ( strRecv == "INP11")  )
	{
		//LC8 intensity reaches MAX value.
		pUI->GetDlgItem(IDC_BUTTON_UV_LAMP_ON)->SetWindowText("Lamp MAX");
		m_bIntensityMax = TRUE;
		m_bIntensityMin = FALSE;
	}	
}

void CUVControl::ParseUVData_LC8Recv_INT(CString strRecv)
{
	int len, i, j;
	CString strTemp;

	len = strRecv.GetLength();
	if( strRecv == "INT0OK" )
	{
		CommSend("INTQ");
	}
	else if( ( (i=strRecv.Find("INT0")) >= 0 ) || ( (i=strRecv.Find("INT100")) >= 0 ) )
	{
		j = len-2;
		strTemp = strRecv.Right(j-(i+2)+1);
		strTemp.Remove('\n');
		strTemp.Remove('\r');

		char *t = strTemp.GetBuffer(10);
		
		m_iIntensity = atoi(t);
		strTemp.ReleaseBuffer();

		m_strIntensity.Format("%d", m_iIntensity);
		
		PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;
		pUI->SetDlgItemText(IDC_EDIT_UV_INTENSITY, m_strIntensity);

		if( m_iIntensity == 0 )
		{
			m_bIntensityMin = TRUE;
		}
		else if( m_iIntensity == 100 )
		{
			m_bIntensityMax = TRUE;
		}
		else
		{
			m_bIntensityMin = FALSE;
			m_bIntensityMax = FALSE;
		}		
	}
}

void CUVControl::ParseUVData_LC8Recv_CNT(CString strRecv)
{
	PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;

	if( (strRecv == "CNT0") || (strRecv == "CNT0OK") )
	{
		m_bControlMode = UV_CONTROL_FRONT;
		pUI->GetDlgItem(IDC_BUTTON_UV_CONTROL)->SetWindowText("FRONT");
	}
	else if( (strRecv == "CNT1") || (strRecv == "CNT1OK") )
	{
		m_bControlMode = UV_CONTROL_COMPORT;
		pUI->GetDlgItem(IDC_BUTTON_UV_CONTROL)->SetWindowText("COM");
	}
}


void CUVControl::ParseUVData_XCiteRecv(CString strRecv)
{
	int len = strRecv.GetLength();
//	int numindex = strRecv.Find('\r');	
	CString strTemp;
	char *chTemp;

	if( strRecv.Find("e") >= 0 )
	{
		return;// error!
	}
	else
	{
		strTemp = strRecv;
		
		switch(m_iQueryXCite)
		{
		case QUERY_XCITE_SWVER:
			{
			//	strTemp = strRecv.Left(numindex);
				chTemp = strTemp.GetBuffer(2);
				int swver = atoi(chTemp);
				strTemp.ReleaseBuffer();
			}
			break;
		case QUERY_XCITE_LAMP_HOUR:
			{
			//	strTemp = strRecv.Left(numindex);
				chTemp = strTemp.GetBuffer(2);
				int lamphour = atoi(chTemp);
				strTemp.ReleaseBuffer();
			}
			break;
		case QUERY_XCITE_UNIT_STATUS:
			{
			//	strTemp = strRecv.Left(numindex);
				chTemp = strTemp.GetBuffer(2);
				int unitstatus = atoi(chTemp);
				strTemp.ReleaseBuffer();
			}
			break;
		case QUERY_XCITE_INTENSITY:
			{
			//	strTemp = strRecv.Left(numindex);
				if(strRecv == "" )
				{
					return;	//command OK!
				}
				chTemp = strTemp.GetBuffer(2);
				int intensity = atoi(chTemp);
				strTemp.ReleaseBuffer();

				switch(intensity)
				{
				case 0:
					m_iIntensity = 0;
					break;
				case 1:
					m_iIntensity = 12;
					break;
				case 2:
					m_iIntensity = 25;
					break;
				case 3:
					m_iIntensity = 50;
					break;
				case 4:
					m_iIntensity = 100;
					break;
				default:
					break;
				}
				m_strIntensity.Format("%d", m_iIntensity);
		
				PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;
				pUI->SetDlgItemText(IDC_EDIT_UV_INTENSITY, m_strIntensity);

			}
			break;
		case QUERY_XCITE_EXPOSURE_TIME:
			{
			//	strTemp = strRecv.Left(numindex);
				if(strRecv == "" )
				{
					return;	//command OK!
				}
				chTemp = strTemp.GetBuffer(2);
				int time = atoi(chTemp);
				strTemp.ReleaseBuffer();

				float ftime = ((float)time) / 10;
				m_iShutterTime = time*100;
				m_strShutterTime.Format("%d", m_iShutterTime);
				PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;
				pUI->SetDlgItemText(IDC_EDIT_UV_SHUTTERTIME, m_strShutterTime);

			}
			break;
		default:
			break;
		}

		m_iQueryXCite = QUERY_XCITE_NULL;
	}	
}


void CUVControl::ControlMode()
{
	CString strSend;
	
	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
			if( m_bControlMode == UV_CONTROL_FRONT )
			{
				strSend = "CNT1";	//change to COM port mode
				m_bControlMode = UV_CONTROL_COMPORT;
			}
			else
			{
				strSend = "CNT0";	//change to Front panel mode
				m_bControlMode = UV_CONTROL_FRONT;
			}
		}
		break;
	case UV_SOURCE_DEVICE_ID_XCITE:
		{
			if( m_bControlMode == UV_CONTROL_FRONT )
			{
			//	strSend = "nn";	//change to COM port mode
				m_bControlMode = UV_CONTROL_COMPORT;
			}
			else
			{
			//	strSend = "ll";	//change to Front panel mode
				m_bControlMode = UV_CONTROL_FRONT;
			}
		}
		break;
	default:
		break;
	}

	CommSend(strSend);
}

void CUVControl::LampControl()
{
	CString strSend;

	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
			if( m_bLampOn == FALSE )
			{		
				strSend = "L1";		// Lamp ON
				m_bLampOn = TRUE;		
			}
			else
			{
				strSend = "L0";		// Lamp OFF
				m_bLampOn = FALSE;		
			}
		}
		break;
	case UV_SOURCE_DEVICE_ID_XCITE:
		{
			if( m_bLampOn == FALSE )
			{		
				strSend = "ss";		// Lamp ON
				m_bLampOn = TRUE;		
			}
			else
			{
				strSend = "ss";		// Lamp OFF
				m_bLampOn = FALSE;		
			}
		}
		break;
	default:
		break;
	}

	CommSend(strSend);
}

void CUVControl::LampControl(BOOL bOnOff)
{
	CString strSend;
	PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;

	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
			if( bOnOff == TRUE )
			{		
				strSend = "L1";		// Lamp ON
				m_bLampOn = TRUE;		
				
				pUI->SetDlgItemText(IDC_STATIC_DEBUG, "L ON");
			}
			else
			{
				strSend = "L0";		// Lamp OFF
				m_bLampOn = FALSE;	
				
				pUI->SetDlgItemText(IDC_STATIC_DEBUG, "L OFF");
			}
		}
		break;
	case UV_SOURCE_DEVICE_ID_XCITE:
		{
			if( bOnOff == TRUE )
			{		
				strSend = "ss";		// Lamp ON
				m_bLampOn = TRUE;		
				
				pUI->SetDlgItemText(IDC_STATIC_DEBUG, "L ON");
			}
			else
			{
				strSend = "ss";		// Lamp OFF
				m_bLampOn = FALSE;	
				
				pUI->SetDlgItemText(IDC_STATIC_DEBUG, "L OFF");
			}
		}
		break;
	default:
		break;
	}

	CommSend(strSend);
}


void CUVControl::ShutterAuto()
{
	CString strSend;
	char *chTemp;
	int iTime;
	PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;

	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
		//	strSend = "ATS";		// Auto shutter	
		//	CommSend(strSend);
			
			ManualShutterControl(TRUE);
			
			pUI->GetDlgItemText(IDC_EDIT_UV_SHUTTERTIME, strSend);
			chTemp = strSend.GetBuffer(strSend.GetLength());	
			iTime = atoi(chTemp);
			strSend.ReleaseBuffer();
			SetMMTimer(TIMER_EVENT_LC8_SHUTTER_AUTO, iTime);
		}
		break;
	case UV_SOURCE_DEVICE_ID_XCITE:
		{
		//	strSend = "oo";
		//	CommSend(strSend);
			ManualShutterControl(TRUE);
			
			pUI->GetDlgItemText(IDC_EDIT_UV_SHUTTERTIME, strSend);
			chTemp = strSend.GetBuffer(strSend.GetLength());	
			iTime = atoi(chTemp);
			strSend.ReleaseBuffer();
			SetMMTimer(TIMER_EVENT_LC8_SHUTTER_AUTO, iTime);
		}
		break;
	default:
		break;
	}

	
}

void CUVControl::ShutterManual()
{
	CString strSend;
	PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;
	
	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
			if( m_bManualOn == FALSE )
			{		
				strSend = "S1";		// Shutter ON
				m_bManualOn = TRUE;
				pUI->GetDlgItem(IDC_BUTTON_UV_SHUTTER_MANUAL)->SetWindowText("Opened");
			}
			else
			{
				strSend = "S0";		// Shutter OFF
				m_bManualOn = FALSE;
				pUI->GetDlgItem(IDC_BUTTON_UV_SHUTTER_MANUAL)->SetWindowText("Closed");
			}
		}
		break;
	case UV_SOURCE_DEVICE_ID_XCITE:
		{
			if( m_bManualOn == FALSE )
			{		
				strSend = "mm";		// Shutter ON
				m_bManualOn = TRUE;
				pUI->GetDlgItem(IDC_BUTTON_UV_SHUTTER_MANUAL)->SetWindowText("Opened");
			}
			else
			{
				strSend = "zz";		// Shutter OFF
				m_bManualOn = FALSE;
				pUI->GetDlgItem(IDC_BUTTON_UV_SHUTTER_MANUAL)->SetWindowText("Closed");
			}
		}
		break;
	default:
		break;
	}

	CommSend(strSend);
}

void CUVControl::ManualShutterControl(BOOL bOpen)
{
	CString strSend;
	PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;

	switch (m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		if( bOpen == TRUE ) // Shutter ON
		{
			strSend = "S1";		// Shutter ON
			m_bManualOn = TRUE;
			pUI->GetDlgItem(IDC_BUTTON_UV_SHUTTER_MANUAL)->SetWindowText("Opened");
		}
		else	// Shutter OFF
		{
			strSend = "S0";		// Shutter OFF
			m_bManualOn = FALSE;
			pUI->GetDlgItem(IDC_BUTTON_UV_SHUTTER_MANUAL)->SetWindowText("Closed");
		}
		break;
	
	case UV_SOURCE_DEVICE_ID_XCITE:
		if( bOpen == TRUE )
		{		
			strSend = "mm";		// Shutter ON
			m_bManualOn = TRUE;
			pUI->GetDlgItem(IDC_BUTTON_UV_SHUTTER_MANUAL)->SetWindowText("Opened");
		}
		else
		{
			strSend = "zz";		// Shutter OFF
			m_bManualOn = FALSE;
			pUI->GetDlgItem(IDC_BUTTON_UV_SHUTTER_MANUAL)->SetWindowText("Closed");
		}
		break;
	}

	CommSend(strSend);
}


void CUVControl::ShutterTimeRead()
{
	CString strSend;
	
	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
			strSend = "ATQ";
		}
		break;
	case UV_SOURCE_DEVICE_ID_XCITE:
		{
			m_iQueryXCite = QUERY_XCITE_EXPOSURE_TIME;
			strSend = "cc";
		}
		break;
	default:
		break;
	}

	CommSend(strSend);
}

void CUVControl::ShutterTimeSet()
{
	CString strSend, strTemp;
	PARENT_CLASS *pUI = (PARENT_CLASS *)m_pParentWnd;
	int iTime;
	float fTimems;
	char *chTemp;

	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
			pUI->GetDlgItemText(IDC_EDIT_UV_SHUTTERTIME, strTemp);
			
			chTemp = strTemp.GetBuffer(strTemp.GetLength());
			iTime = atoi(chTemp);
			strTemp.ReleaseBuffer();

			fTimems = (float)(iTime) / 1000;
			strTemp.Format("%.1f", fTimems);
			if(strTemp.GetLength() < 4 )
			{
				strTemp.Insert(0, '0');
			}

			strSend = "AT0";
			strSend += strTemp;
			CommSend(strSend);
		}
		break;
	case UV_SOURCE_DEVICE_ID_XCITE:
		{
			pUI->GetDlgItemText(IDC_EDIT_UV_SHUTTERTIME, strTemp);
			chTemp = strTemp.GetBuffer(strTemp.GetLength());
			fTimems = (float)(atof(chTemp)) / 1000;

			if( (fTimems > (float)9999) || (fTimems < 0.2) )
			{
				return;
			}

			iTime = (int)(fTimems * 10);
			if( fTimems < (float)1 )
			{				
				strTemp.Format("000%d", iTime);
			}
			else
			{
				if( iTime >= 100 )
				{
					strTemp.Format("%d", iTime);
				}
				else if( iTime >= 10 )
				{
					strTemp.Format("0%d", iTime);
				}
				else// if( iTime >= 1000 )
				{
					strTemp.Format("00%d", iTime);
				}
			}
			strSend = "c";
			strSend += strTemp;
			CommSend(strSend);
			SetMMTimer(TIMER_EVENT_XCITE_READ_SHUTTERTIME, 200);
		}
		break;
	default:
		break;
	}	
}

void CUVControl::IntensityControl(BOOL bUpDown)
{
	CString strSend;
	
	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
			if( bUpDown == TRUE )	//Up
			{
				m_iIntensity++;
				if(m_iIntensity > 100 )
				{
					m_iIntensity = 100;
					return;
				}
				strSend = "INT1";
			}
			else		//Down
			{
				m_iIntensity--;
				if(m_iIntensity < 0 )
				{
					m_iIntensity = 0;
					return;
				}
				strSend = "INT2";
			}
			CommSend(strSend);
			SetMMTimer(TIMER_EVENT_INTENSITY_CONTROL, 35);
		}
		break;
	case UV_SOURCE_DEVICE_ID_XCITE:
		{
			m_iQueryXCite = QUERY_XCITE_INTENSITY;

			if( bUpDown == TRUE )	//Up
			{
				m_iXCiteUVIntensityIndex++;
				if( m_iXCiteUVIntensityIndex > 4) 
				{
					m_iXCiteUVIntensityIndex = 4;
					return;
				}
			}
			else		//Down
			{
				m_iXCiteUVIntensityIndex--;
				if( m_iXCiteUVIntensityIndex < 0) 
				{
					m_iXCiteUVIntensityIndex = 0;
					return;
				}
			}
			
			strSend.Format("i%d", m_iXCiteUVIntensityIndex);
			CommSend(strSend);
			SetMMTimer(TIMER_EVENT_XCITE_READ_INTENSITY, 200);		
		}
		break;
	default:
		break;
	}	
}

void CUVControl::IntensityRead()
{
	CString strSend;
	
	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
			strSend = "ATQ";
		}
		break;
	case UV_SOURCE_DEVICE_ID_XCITE:
		{
			m_iQueryXCite = QUERY_XCITE_INTENSITY;
			strSend = "ii";
		}
		break;
	default:
		break;
	}

	CommSend(strSend);
}
	
//============================================================================

void CUVControl::ReadLampStatus()
{
//	CString strSend;
	switch(m_iDeviceID)
	{
	case UV_SOURCE_DEVICE_ID_LC8:
		{
			CommSend("INP");
			Sleep(100);

			CommSend("ATQ");
			Sleep(100);
				
			CommSend("INTQ");
			Sleep(100);

			CommSend("CNTQ");
			Sleep(100);
		}
		break;
	case UV_SOURCE_DEVICE_ID_XCITE:
		{
			CommSend("tt");	// connect			
		}
	}	
}


//======= Multimedia Timer of UV: Callback Function ================================
void CALLBACK MMUVTimerProcess( UINT uID, UINT uMsg, DWORD dwUser, DWORD dw1, DWORD dw2)
{
	CUVControl* pClass = (CUVControl*) dwUser;
    //pClass ̿ ó

	switch(pClass->m_iTimerEvent)
	{
	case TIMER_EVENT_QUERY_UV_STATUS:
		switch(pClass->m_iDeviceID)
		{
		case UV_SOURCE_DEVICE_ID_LC8:
			::timeKillEvent(uID);
			pClass->ReadLampStatus();
			break;
		case UV_SOURCE_DEVICE_ID_XCITE:
			switch(pClass->m_iXCiteStatusStep)
			{
			case 0:
				::timeKillEvent(uID);
				pClass->ConnectXCite();
				pClass->m_iXCiteStatusStep++;
				pClass->SetMMTimer(TIMER_EVENT_QUERY_UV_STATUS, 200);
				break;
			case 1:
				pClass->IntensityRead();
				pClass->m_iXCiteStatusStep++;
				break;
			case 2:	
				::timeKillEvent(uID);
				pClass->ShutterTimeRead();
				pClass->m_iXCiteStatusStep = 0;
				break;
			default:
				break;
			}
			break;
		default:
			break;
		}		
		break;
	case TIMER_EVENT_INTENSITY_CONTROL:
		pClass->CommSend("INT0");		
		::timeKillEvent(uID);
		break;
	case TIMER_EVENT_XCITE_READ_INTENSITY:
		pClass->IntensityRead();
		::timeKillEvent(uID);
		break;
	case TIMER_EVENT_XCITE_READ_SHUTTERTIME:
		pClass->ShutterTimeRead();
		::timeKillEvent(uID);
		break;
	case TIMER_EVENT_LC8_SHUTTER_AUTO:
		pClass->ManualShutterControl(FALSE);
		::timeKillEvent(uID);
		break;
	default:
		break;
	}
	
}


void CUVControl::ConnectXCite()
{
	CommSend("tt");	// connect
}

void CUVControl::SetMMTimer(int iEvent, int iTime)
{
	m_iTimerEvent = iEvent;
	m_nTimerID = ::timeSetEvent(iTime, DEFAULT_MMTIMER_RESOLUTION, 
									(LPTIMECALLBACK) MMUVTimerProcess,
									(DWORD) this, TIME_PERIODIC | TIME_CALLBACK_FUNCTION);
}

void CUVControl::ReceiveData()
{
	CString strReceive;
	int iReceiveLen, i;

	m_pComPort->receiveString( strReceive );
	iReceiveLen = strReceive.GetLength();

	for(i=0;i<iReceiveLen;i++)
	{
		if( (strReceive.GetAt(i) == '\r') || (strReceive.GetAt(i) == '\n') )
		{
			ParseUVData(m_strUVCommRecv);
			m_strUVCommRecv = "";
		}
		else
		{			
			m_strUVCommRecv += strReceive.GetAt(i);
		}
	}
}

void CUVControl::SetComPortInfo(CComPortUI *pComPortUI)
{
	pComPortUI->m_iBaudrate = 9600;
	pComPortUI->m_iComPort = DEFAULT_UV_COMPORT;
	CString strComPort;
	strComPort.Format("COM%d", pComPortUI->m_iComPort);
	pComPortUI->m_strComPort = strComPort;
}

void CUVControl::UVControl(CString strUVControl)
{
	if( (strUVControl == "ON") || (strUVControl == "on") )
	{
		ManualShutterControl(TRUE);
	}
	else if( (strUVControl == "OFF") || (strUVControl == "off") )
	{
		ManualShutterControl(FALSE);
	}
}
